PyPoscar API — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# PyPoscar API

This chapter is intended to describe pyposcar and the analysis of real-space features

PyPoscar has the following data types:

- `pyprocar.pyposcar.Poscar` low-level storage and manipulation of an input crystal structure POSCAR-like format.

- `pyprocar.pyposcar.poscar_modify` general utility to manipulate a crystal structure.

- Poscar
  - pyprocar.pyposcar.Poscar
- poscarUtils
  - pyprocar.pyposcar.poscar_modify
  - pyprocar.pyposcar.poscar_supercell
  - poscarDiff